diff --git a/saqc/funcs/constants.py b/saqc/funcs/constants.py
index b1c68ee1009db4633b90ff5cf8e20ef35d96a107..974039edbd05885287ecb8470a3c2d48cfd9839a 100644
--- a/saqc/funcs/constants.py
+++ b/saqc/funcs/constants.py
@@ -51,18 +51,18 @@ class ConstantsMixin:
         thresh :
             Maximum total change allowed per window.
 
+        window :
+            Size of the moving window. This determines the number of observations used
+            for calculating the absolute change per window.
+            Each window will be of either of a fixed number of periods (integer defined window),
+            or will have a fixed temporal extension (offset defined window).
+
         min_periods :
             Minimum number of observations in window required to generate
             a flag. Must be an integer greater or equal `2`, because a
             single value would always be considered constant.
             Defaults to `2`.
-
-        window :
-            Size of the moving window. This is the number of observations used
-            for calculating the statistic. Each window will be a fixed size.
-            If it is an offset then this will be the time period of each window.
-            Each window will be a variable sized based on the observations included
-            in the time-period.
         """
         d: pd.Series = self._data[field]
         validateWindow(window, index=d.index)
@@ -51,18 +51,18 @@ class ConstantsMixin:
         min_periods :
             Minimum number of observations in window required to generate
-            a flag. Must be an integer greater or equal `2`, because a
+            a flag. This is to exclude underpopulated offset defined windows from flagging.
+            Must be an integer greater or equal `2`, because a
             single value would always be considered constant.
             Defaults to `2`.